@@ -1,17 +1,18 @@
 from .dreamer import *
 from .utils import *
-from .models import *
 from .model_bunch import *
 from .tests import *
+from .auto_image_param import auto_image_param
+from .custom_image_param import custom_image_param
 
-__version__ = "2.0.3"
+__version__ = "2.1.0"
 
 __all__ = [
     "dreamer",
     "utils",
-    "models",
     "model_bunch",
     "auto_image_param",
+    "custom_image_param",
     "image_transforms",
     "transforms"
 ]
