@@ -2,27 +2,26 @@ import torch
 from tqdm import tqdm
 from copy import deepcopy
 import torchvision.transforms as transforms
-from .dreamer_utils import Hook, default_func_mean
 
 from .utils import (
     fft_to_rgb, 
     lucid_colorspace_to_rgb, 
     normalize, 
-    show_rgb
 )
 
 from .transforms import random_resize
 from .auto_image_param import auto_image_param
+from .dreamer_utils import Hook, default_func_mean
 
 class dreamer():
-    """wrapper over a pytorch model for visualization
+    """wrapper over a pytorch model for feature visualization
 
         Args:
             model (torch.nn.Module): pytorch model 
             quiet (bool, optional): enable or disable progress bar. Defaults to True.
             device (str, optional): 'cpu' or 'cuda'. Defaults to 'cuda'.
     """
-    def __init__(self, model, quiet = True, device = 'cuda'):
+    def __init__(self, model, quiet = False, device = 'cuda'):
         
         self.model = model 
         self.model.eval()
@@ -66,7 +65,6 @@ class dreamer():
             image_parameter instance: To show image, use: plt.imshow(image_parameter.rgb)
         """
         if image_parameter is None:
-
             image_parameter = auto_image_param(height= height, width = width, device = self.device, standard_deviation = 0.01)
         else:
             image_parameter = deepcopy(image_parameter)
@@ -83,12 +81,10 @@ class dreamer():
             hooks.append(hook)
 
         for i in tqdm(range(iters), disable= self.quiet):
+            
             image_parameter.optimizer.zero_grad()
 
-            img = fft_to_rgb(image_parameter.height, image_parameter.width, image_parameter.param, device= self.device)
-            img = lucid_colorspace_to_rgb(img,device= self.device)
-            img = torch.sigmoid(img)
-            img = normalize(img, device= self.device)
+            img = image_parameter.forward(device = self.device)
             img = self.transforms(img)
 
             model_out = self.model(img)
@@ -104,7 +100,7 @@ class dreamer():
             else:
                 loss = self.default_func(layer_outputs)
             loss.backward()
-            image_parameter.clip_grads(grad_clip= 1)
+            image_parameter.clip_grads(grad_clip= grad_clip)
             image_parameter.optimizer.step()
         
 
@@ -114,6 +110,15 @@ class dreamer():
         return image_parameter
     
     def get_snapshot(self, layers, input_tensor):
+        """Registers the outputs of a set of layers within a model
+
+        Args:
+            layers (list): [model.layer1, model.layer2,...]
+            input_tensor (torch.Tensor): NCHW tensor to be fed into the model
+
+        Returns:
+            [list]: list of layer outputs
+        """
 
         with torch.no_grad():
             input_tensor = input_tensor.to(self.device)
